/* Generated by Cython 0.28.5 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "metaphor.monal.util.const_st",
        "sources": [
            "metaphor/monal/util/const_st.py"
        ]
    },
    "module_name": "metaphor.monal.util.const_st"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_28_5"
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (0 && PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0; // PyThread_create_key reports success always
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif // TSS (Thread Specific Storage) API
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
  #define PyObject_Unicode             PyObject_Str
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : (Py_INCREF(func), func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif


#define __PYX_ERR(f_index, lineno, Ln_error) \
{ \
  __pyx_filename = __pyx_f[f_index]; __pyx_lineno = lineno; __pyx_clineno = __LINE__; goto Ln_error; \
}

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__metaphor__monal__util__const_st
#define __PYX_HAVE_API__metaphor__monal__util__const_st
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "metaphor/monal/util/const_st.py",
};

/*--- Type declarations ---*/

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* GetModuleGlobalName.proto */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);


/* Module declarations from 'metaphor.monal.util.const_st' */
#define __Pyx_MODULE_NAME "metaphor.monal.util.const_st"
extern int __pyx_module_is_main_metaphor__monal__util__const_st;
int __pyx_module_is_main_metaphor__monal__util__const_st = 0;

/* Implementation of 'metaphor.monal.util.const_st' */
static PyObject *__pyx_builtin_TypeError;
static const char __pyx_k_n[] = "n";
static const char __pyx_k_q[] = "q";
static const char __pyx_k_MU[] = "MU";
static const char __pyx_k_pi[] = "pi";
static const char __pyx_k_1_0[] = "1.0";
static const char __pyx_k_COL[] = "COL";
static const char __pyx_k_ZTZ[] = "ZTZ";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_num[] = "num";
static const char __pyx_k_row[] = "row";
static const char __pyx_k_DATA[] = "DATA";
static const char __pyx_k_ITEM[] = "ITEM";
static const char __pyx_k_LINK[] = "LINK";
static const char __pyx_k_NODE[] = "NODE";
static const char __pyx_k_N__s[] = "N_%s";
static const char __pyx_k_REAL[] = "REAL";
static const char __pyx_k_W__d[] = "W_%d";
static const char __pyx_k_bias[] = "bias";
static const char __pyx_k_kind[] = "kind";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_rank[] = "rank";
static const char __pyx_k_st_n[] = "st_n";
static const char __pyx_k_st_q[] = "st_q";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_IN__d[] = "IN_%d";
static const char __pyx_k_LAYER[] = "LAYER";
static const char __pyx_k_MODEL[] = "MODEL";
static const char __pyx_k_PRESS[] = "PRESS";
static const char __pyx_k_VALUE[] = "VALUE";
static const char __pyx_k_activ[] = "activ";
static const char __pyx_k_biais[] = "biais";
static const char __pyx_k_class[] = "class";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_jrank[] = "jrank";
static const char __pyx_k_layer[] = "layer";
static const char __pyx_k_nname[] = "nname";
static const char __pyx_k_order[] = "order";
static const char __pyx_k_sigma[] = "sigma";
static const char __pyx_k_st_MU[] = "st_MU";
static const char __pyx_k_st_pi[] = "st_pi";
static const char __pyx_k_style[] = "style";
static const char __pyx_k_H_d__d[] = "H%d_%d";
static const char __pyx_k_Neuron[] = "Neuron";
static const char __pyx_k_OUT__d[] = "OUT_%d";
static const char __pyx_k_inputs[] = "inputs";
static const char __pyx_k_linkid[] = "linkid";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_nodeid[] = "nodeid";
static const char __pyx_k_output[] = "output";
static const char __pyx_k_st_COL[] = "st_COL";
static const char __pyx_k_st_ZTZ[] = "st_ZTZ";
static const char __pyx_k_st_num[] = "st_num";
static const char __pyx_k_st_row[] = "st_row";
static const char __pyx_k_NETWORK[] = "NETWORK";
static const char __pyx_k_STUDENT[] = "STUDENT";
static const char __pyx_k_WEIGHTS[] = "WEIGHTS";
static const char __pyx_k_outputs[] = "outputs";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_project[] = "project";
static const char __pyx_k_reverse[] = "reverse";
static const char __pyx_k_st_DATA[] = "st_DATA";
static const char __pyx_k_st_ITEM[] = "st_ITEM";
static const char __pyx_k_st_LINK[] = "st_LINK";
static const char __pyx_k_st_NODE[] = "st_NODE";
static const char __pyx_k_st_REAL[] = "st_REAL";
static const char __pyx_k_st_bias[] = "st_bias";
static const char __pyx_k_st_kind[] = "st_kind";
static const char __pyx_k_st_name[] = "st_name";
static const char __pyx_k_st_rank[] = "st_rank";
static const char __pyx_k_version[] = "version";
static const char __pyx_k_weights[] = "weights";
static const char __pyx_k_NOISEVAR[] = "NOISEVAR";
static const char __pyx_k_NeuronPi[] = "NeuronPi";
static const char __pyx_k_function[] = "function";
static const char __pyx_k_parentid[] = "parentid";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_st_DiErr[] = "st_DiErr";
static const char __pyx_k_st_LAYER[] = "st_LAYER";
static const char __pyx_k_st_MODEL[] = "st_MODEL";
static const char __pyx_k_st_PRESS[] = "st_PRESS";
static const char __pyx_k_st_VALUE[] = "st_VALUE";
static const char __pyx_k_st_activ[] = "st_activ";
static const char __pyx_k_st_class[] = "st_class";
static const char __pyx_k_st_count[] = "st_count";
static const char __pyx_k_st_jrank[] = "st_jrank";
static const char __pyx_k_st_layer[] = "st_layer";
static const char __pyx_k_st_nname[] = "st_nname";
static const char __pyx_k_st_order[] = "st_order";
static const char __pyx_k_st_sigma[] = "st_sigma";
static const char __pyx_k_st_style[] = "st_style";
static const char __pyx_k_CONFLEVEL[] = "CONFLEVEL";
static const char __pyx_k_STUDENT95[] = "STUDENT95";
static const char __pyx_k_TRAINCOST[] = "TRAINCOST";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_inputname[] = "inputname";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_st_Neuron[] = "st_Neuron";
static const char __pyx_k_st_inputs[] = "st_inputs";
static const char __pyx_k_st_linkid[] = "st_linkid";
static const char __pyx_k_st_nodeid[] = "st_nodeid";
static const char __pyx_k_st_output[] = "st_output";
static const char __pyx_k_xmlns_xsi[] = "xmlns:xsi";
static const char __pyx_k_CONFIDENCE[] = "CONFIDENCE";
static const char __pyx_k_ConstError[] = "ConstError";
static const char __pyx_k_ISO_8859_1[] = "ISO-8859-1";
static const char __pyx_k_MULTIMODEL[] = "MULTIMODEL";
static const char __pyx_k_NORMALIZER[] = "NORMALIZER";
static const char __pyx_k_neuronname[] = "neuronname";
static const char __pyx_k_outputname[] = "outputname";
static const char __pyx_k_st_NETWORK[] = "st_NETWORK";
static const char __pyx_k_st_STUDENT[] = "st_STUDENT";
static const char __pyx_k_st_WEIGHTS[] = "st_WEIGHTS";
static const char __pyx_k_st_outputs[] = "st_outputs";
static const char __pyx_k_st_project[] = "st_project";
static const char __pyx_k_st_reverse[] = "st_reverse";
static const char __pyx_k_st_version[] = "st_version";
static const char __pyx_k_st_weights[] = "st_weights";
static const char __pyx_k_NeuronSigma[] = "NeuronSigma";
static const char __pyx_k_st_Encoding[] = "st_Encoding";
static const char __pyx_k_st_ModelURL[] = "st_ModelURL";
static const char __pyx_k_st_NOISEVAR[] = "st_NOISEVAR";
static const char __pyx_k_st_NeuronPi[] = "st_NeuronPi";
static const char __pyx_k_st_NodeList[] = "st_NodeList";
static const char __pyx_k_st_function[] = "st_function";
static const char __pyx_k_st_normName[] = "st_normName";
static const char __pyx_k_st_parentid[] = "st_parentid";
static const char __pyx_k_synapsename[] = "synapsename";
static const char __pyx_k_Empty_vector[] = "Empty vector";
static const char __pyx_k_st_CONFLEVEL[] = "st_CONFLEVEL";
static const char __pyx_k_st_INdefault[] = "st_INdefault";
static const char __pyx_k_st_ModelList[] = "st_ModelList";
static const char __pyx_k_st_NoCostFct[] = "st_NoCostFct";
static const char __pyx_k_st_STUDENT95[] = "st_STUDENT95";
static const char __pyx_k_st_TRAINCOST[] = "st_TRAINCOST";
static const char __pyx_k_st_XMLHeader[] = "st_XMLHeader";
static const char __pyx_k_st_XMLSchema[] = "st_XMLSchema";
static const char __pyx_k_st_inputname[] = "st_inputname";
static const char __pyx_k_st_xmlns_xsi[] = "st_xmlns_xsi";
static const char __pyx_k_stl_biasname[] = "stl_biasname";
static const char __pyx_k_st_BadInputNb[] = "st_BadInputNb";
static const char __pyx_k_st_CONFIDENCE[] = "st_CONFIDENCE";
static const char __pyx_k_st_EmptVecErr[] = "st_EmptVecErr";
static const char __pyx_k_st_HIDdefault[] = "st_HIDdefault";
static const char __pyx_k_st_MULTIMODEL[] = "st_MULTIMODEL";
static const char __pyx_k_st_NORMALIZER[] = "st_NORMALIZER";
static const char __pyx_k_st_NeedNetDef[] = "st_NeedNetDef";
static const char __pyx_k_st_NoModelErr[] = "st_NoModelErr";
static const char __pyx_k_st_OUTdefault[] = "st_OUTdefault";
static const char __pyx_k_st_SynLinkErr[] = "st_SynLinkErr";
static const char __pyx_k_st_SynReadErr[] = "st_SynReadErr";
static const char __pyx_k_st_XMLVersion[] = "st_XMLVersion";
static const char __pyx_k_st_neuronname[] = "st_neuronname";
static const char __pyx_k_st_outputname[] = "st_outputname";
static const char __pyx_k_st_BackPropErr[] = "st_BackPropErr";
static const char __pyx_k_st_NeuronSigma[] = "st_NeuronSigma";
static const char __pyx_k_st_XMLEncoding[] = "st_XMLEncoding";
static const char __pyx_k_st_synapsename[] = "st_synapsename";
static const char __pyx_k_Dimension_error[] = "Dimension error";
static const char __pyx_k_st_ArchLayerErr[] = "st_ArchLayerErr";
static const char __pyx_k_st_XMLSchemaLoc[] = "st_XMLSchemaLoc";
static const char __pyx_k_Bad_input_number[] = "Bad input number";
static const char __pyx_k_st_CantDelVecErr[] = "st_CantDelVecErr";
static const char __pyx_k_st_WEIGHTdefault[] = "st_WEIGHTdefault";
static const char __pyx_k_st_XMLStyleSheet[] = "st_XMLStyleSheet";
static const char __pyx_k_st_negativeInput[] = "st_negativeInput";
static const char __pyx_k_st_TrainErrorCode[] = "st_TrainErrorCode";
static const char __pyx_k_st_WeightReadMErr[] = "st_WeightReadMErr";
static const char __pyx_k_st_WeightWritMErr[] = "st_WeightWritMErr";
static const char __pyx_k_STANDARD_DEVIATION[] = "STANDARD_DEVIATION";
static const char __pyx_k_Train_Error_code_d[] = "Train Error code = %d";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_st_ActivationError[] = "st_ActivationError";
static const char __pyx_k_st_CostComputeDisp[] = "st_CostComputeDisp";
static const char __pyx_k_st_CostFuncUnknown[] = "st_CostFuncUnknown";
static const char __pyx_k_st_NeedFunctionName[] = "st_NeedFunctionName";
static const char __pyx_k_Synapse_linking_error[] = "Synapse linking error";
static const char __pyx_k_Synapse_reading_Error[] = "Synapse reading Error";
static const char __pyx_k_st_STANDARD_DEVIATION[] = "st_STANDARD_DEVIATION";
static const char __pyx_k_No_Model_in_the_Driver[] = "No Model in the Driver";
static const char __pyx_k_Cost_function_s_unknown[] = "Cost function \"%s\" unknown";
static const char __pyx_k_st_IndexErrorWithLimits[] = "st_IndexErrorWithLimits";
static const char __pyx_k_Error_in_backpropagation[] = "Error in backpropagation";
static const char __pyx_k_xml_version_s_encoding_s[] = "<?xml version=\"%s\" encoding=\"%s\"?>";
static const char __pyx_k_Index_Error_Should_be_d_d_d[] = "Index Error. Should be %d <= %d < %d";
static const char __pyx_k_metaphor_monal_util_const_st[] = "metaphor.monal.util.const_st";
static const char __pyx_k_st_ActivationDerivativeError[] = "st_ActivationDerivativeError";
static const char __pyx_k_st_NamedIndexErrorWithLimits[] = "st_NamedIndexErrorWithLimits";
static const char __pyx_k_xml_stylesheet_type_text_xsl[] = "<?xml-stylesheet type=\"text/xsl\"?>";
static const char __pyx_k_Need_at_least_a_function_name[] = "Need at least a function name";
static const char __pyx_k_s_Index_Error_Should_be_d_d_d[] = "%s Index Error. Should be %d <= (%d) < %d";
static const char __pyx_k_st_ActivationDerivative2Error[] = "st_ActivationDerivative2Error";
static const char __pyx_k_xsi_noNamespaceSchemaLocation[] = "xsi:noNamespaceSchemaLocation";
static const char __pyx_k_Activation_derivative_error_s_in[] = "Activation derivative error %s in node='%s' for activation='%s', potential=%f";
static const char __pyx_k_Activation_error_s_in_node_s_for[] = "Activation error %s in node='%s' for activation='%s', potential=%f";
static const char __pyx_k_Activation_second_derivative_err[] = "Activation second derivative error %s in node='%s' for activation='%s', potential=%f, derivative=%f";
static const char __pyx_k_Architecture_error_in_NODE_LAYER[] = "Architecture error in NODE/LAYER parentship";
static const char __pyx_k_Cost_compute_s_line_d_for_vcal_f[] = "Cost compute %s line=%d for vcal=%f, vdes=%s";
static const char __pyx_k_Sorry_the_cost_function_is_unkno[] = "Sorry, the cost function is unknown";
static const char __pyx_k_Weight_reading_Error_in_MultiMod[] = "Weight reading Error in MultiModel";
static const char __pyx_k_Weight_writing_Error_in_MultiMod[] = "Weight writing Error in MultiModel";
static const char __pyx_k_can_t_delete_item_from_fixed_vec[] = "can't delete item from fixed vector";
static const char __pyx_k_http_www_netral_com_public_xml_x[] = "http://www.netral.com/public/xml/xsd/model.xsd";
static const char __pyx_k_http_www_w3_org_2001_XMLSchema_i[] = "http://www.w3.org/2001/XMLSchema-instance";
static const char __pyx_k_need_a_path_to_model_file_or_a_n[] = "need a path to model file, or a network definition";
static const char __pyx_k_negative_number_of_inputs_output[] = "negative number of inputs + outputs";
static PyObject *__pyx_kp_u_1_0;
static PyObject *__pyx_kp_u_Activation_derivative_error_s_in;
static PyObject *__pyx_kp_u_Activation_error_s_in_node_s_for;
static PyObject *__pyx_kp_u_Activation_second_derivative_err;
static PyObject *__pyx_kp_u_Architecture_error_in_NODE_LAYER;
static PyObject *__pyx_kp_u_Bad_input_number;
static PyObject *__pyx_n_u_COL;
static PyObject *__pyx_n_u_CONFIDENCE;
static PyObject *__pyx_n_u_CONFLEVEL;
static PyObject *__pyx_n_s_ConstError;
static PyObject *__pyx_kp_u_Cost_compute_s_line_d_for_vcal_f;
static PyObject *__pyx_kp_u_Cost_function_s_unknown;
static PyObject *__pyx_n_u_DATA;
static PyObject *__pyx_kp_u_Dimension_error;
static PyObject *__pyx_kp_u_Empty_vector;
static PyObject *__pyx_kp_u_Error_in_backpropagation;
static PyObject *__pyx_kp_u_H_d__d;
static PyObject *__pyx_kp_u_IN__d;
static PyObject *__pyx_kp_u_ISO_8859_1;
static PyObject *__pyx_n_u_ITEM;
static PyObject *__pyx_kp_u_Index_Error_Should_be_d_d_d;
static PyObject *__pyx_n_u_LAYER;
static PyObject *__pyx_n_u_LINK;
static PyObject *__pyx_n_u_MODEL;
static PyObject *__pyx_n_u_MU;
static PyObject *__pyx_n_u_MULTIMODEL;
static PyObject *__pyx_n_u_NETWORK;
static PyObject *__pyx_n_u_NODE;
static PyObject *__pyx_n_u_NOISEVAR;
static PyObject *__pyx_n_u_NORMALIZER;
static PyObject *__pyx_kp_u_N__s;
static PyObject *__pyx_kp_u_Need_at_least_a_function_name;
static PyObject *__pyx_n_u_Neuron;
static PyObject *__pyx_n_u_NeuronPi;
static PyObject *__pyx_n_u_NeuronSigma;
static PyObject *__pyx_kp_u_No_Model_in_the_Driver;
static PyObject *__pyx_kp_u_OUT__d;
static PyObject *__pyx_n_u_PRESS;
static PyObject *__pyx_n_u_REAL;
static PyObject *__pyx_n_u_STANDARD_DEVIATION;
static PyObject *__pyx_n_u_STUDENT;
static PyObject *__pyx_n_u_STUDENT95;
static PyObject *__pyx_kp_u_Sorry_the_cost_function_is_unkno;
static PyObject *__pyx_kp_u_Synapse_linking_error;
static PyObject *__pyx_kp_u_Synapse_reading_Error;
static PyObject *__pyx_n_u_TRAINCOST;
static PyObject *__pyx_kp_u_Train_Error_code_d;
static PyObject *__pyx_n_s_TypeError;
static PyObject *__pyx_n_u_VALUE;
static PyObject *__pyx_n_u_WEIGHTS;
static PyObject *__pyx_kp_u_W__d;
static PyObject *__pyx_kp_u_Weight_reading_Error_in_MultiMod;
static PyObject *__pyx_kp_u_Weight_writing_Error_in_MultiMod;
static PyObject *__pyx_n_u_ZTZ;
static PyObject *__pyx_n_u_activ;
static PyObject *__pyx_n_u_biais;
static PyObject *__pyx_n_u_bias;
static PyObject *__pyx_kp_u_can_t_delete_item_from_fixed_vec;
static PyObject *__pyx_n_u_class;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_u_count;
static PyObject *__pyx_n_s_doc;
static PyObject *__pyx_n_u_function;
static PyObject *__pyx_kp_u_http_www_netral_com_public_xml_x;
static PyObject *__pyx_kp_u_http_www_w3_org_2001_XMLSchema_i;
static PyObject *__pyx_n_u_inputname;
static PyObject *__pyx_n_u_inputs;
static PyObject *__pyx_n_u_jrank;
static PyObject *__pyx_n_u_kind;
static PyObject *__pyx_n_u_layer;
static PyObject *__pyx_n_u_linkid;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_metaclass;
static PyObject *__pyx_n_s_metaphor_monal_util_const_st;
static PyObject *__pyx_n_s_module;
static PyObject *__pyx_n_u_n;
static PyObject *__pyx_n_u_name;
static PyObject *__pyx_kp_u_need_a_path_to_model_file_or_a_n;
static PyObject *__pyx_kp_u_negative_number_of_inputs_output;
static PyObject *__pyx_n_u_neuronname;
static PyObject *__pyx_n_u_nname;
static PyObject *__pyx_n_u_nodeid;
static PyObject *__pyx_n_u_num;
static PyObject *__pyx_n_u_order;
static PyObject *__pyx_n_u_output;
static PyObject *__pyx_n_u_outputname;
static PyObject *__pyx_n_u_outputs;
static PyObject *__pyx_n_u_parentid;
static PyObject *__pyx_n_u_pi;
static PyObject *__pyx_n_s_prepare;
static PyObject *__pyx_n_u_project;
static PyObject *__pyx_n_u_q;
static PyObject *__pyx_n_s_qualname;
static PyObject *__pyx_n_u_rank;
static PyObject *__pyx_n_u_reverse;
static PyObject *__pyx_n_u_row;
static PyObject *__pyx_kp_u_s_Index_Error_Should_be_d_d_d;
static PyObject *__pyx_n_u_sigma;
static PyObject *__pyx_n_s_st_ActivationDerivative2Error;
static PyObject *__pyx_n_s_st_ActivationDerivativeError;
static PyObject *__pyx_n_s_st_ActivationError;
static PyObject *__pyx_n_s_st_ArchLayerErr;
static PyObject *__pyx_n_s_st_BackPropErr;
static PyObject *__pyx_n_s_st_BadInputNb;
static PyObject *__pyx_n_s_st_COL;
static PyObject *__pyx_n_s_st_CONFIDENCE;
static PyObject *__pyx_n_s_st_CONFLEVEL;
static PyObject *__pyx_n_s_st_CantDelVecErr;
static PyObject *__pyx_n_s_st_CostComputeDisp;
static PyObject *__pyx_n_s_st_CostFuncUnknown;
static PyObject *__pyx_n_s_st_DATA;
static PyObject *__pyx_n_s_st_DiErr;
static PyObject *__pyx_n_s_st_EmptVecErr;
static PyObject *__pyx_n_s_st_Encoding;
static PyObject *__pyx_n_s_st_HIDdefault;
static PyObject *__pyx_n_s_st_INdefault;
static PyObject *__pyx_n_s_st_ITEM;
static PyObject *__pyx_n_s_st_IndexErrorWithLimits;
static PyObject *__pyx_n_s_st_LAYER;
static PyObject *__pyx_n_s_st_LINK;
static PyObject *__pyx_n_s_st_MODEL;
static PyObject *__pyx_n_s_st_MU;
static PyObject *__pyx_n_s_st_MULTIMODEL;
static PyObject *__pyx_n_s_st_ModelList;
static PyObject *__pyx_n_s_st_ModelURL;
static PyObject *__pyx_n_s_st_NETWORK;
static PyObject *__pyx_n_s_st_NODE;
static PyObject *__pyx_n_s_st_NOISEVAR;
static PyObject *__pyx_n_s_st_NORMALIZER;
static PyObject *__pyx_n_s_st_NamedIndexErrorWithLimits;
static PyObject *__pyx_n_s_st_NeedFunctionName;
static PyObject *__pyx_n_s_st_NeedNetDef;
static PyObject *__pyx_n_s_st_Neuron;
static PyObject *__pyx_n_s_st_NeuronPi;
static PyObject *__pyx_n_s_st_NeuronSigma;
static PyObject *__pyx_n_s_st_NoCostFct;
static PyObject *__pyx_n_s_st_NoModelErr;
static PyObject *__pyx_n_s_st_NodeList;
static PyObject *__pyx_n_s_st_OUTdefault;
static PyObject *__pyx_n_s_st_PRESS;
static PyObject *__pyx_n_s_st_REAL;
static PyObject *__pyx_n_s_st_STANDARD_DEVIATION;
static PyObject *__pyx_n_s_st_STUDENT;
static PyObject *__pyx_n_s_st_STUDENT95;
static PyObject *__pyx_n_s_st_SynLinkErr;
static PyObject *__pyx_n_s_st_SynReadErr;
static PyObject *__pyx_n_s_st_TRAINCOST;
static PyObject *__pyx_n_s_st_TrainErrorCode;
static PyObject *__pyx_n_s_st_VALUE;
static PyObject *__pyx_n_s_st_WEIGHTS;
static PyObject *__pyx_n_s_st_WEIGHTdefault;
static PyObject *__pyx_n_s_st_WeightReadMErr;
static PyObject *__pyx_n_s_st_WeightWritMErr;
static PyObject *__pyx_n_s_st_XMLEncoding;
static PyObject *__pyx_n_s_st_XMLHeader;
static PyObject *__pyx_n_s_st_XMLSchema;
static PyObject *__pyx_n_s_st_XMLSchemaLoc;
static PyObject *__pyx_n_s_st_XMLStyleSheet;
static PyObject *__pyx_n_s_st_XMLVersion;
static PyObject *__pyx_n_s_st_ZTZ;
static PyObject *__pyx_n_s_st_activ;
static PyObject *__pyx_n_s_st_bias;
static PyObject *__pyx_n_s_st_class;
static PyObject *__pyx_n_s_st_count;
static PyObject *__pyx_n_s_st_function;
static PyObject *__pyx_n_s_st_inputname;
static PyObject *__pyx_n_s_st_inputs;
static PyObject *__pyx_n_s_st_jrank;
static PyObject *__pyx_n_s_st_kind;
static PyObject *__pyx_n_s_st_layer;
static PyObject *__pyx_n_s_st_linkid;
static PyObject *__pyx_n_s_st_n;
static PyObject *__pyx_n_s_st_name;
static PyObject *__pyx_n_s_st_negativeInput;
static PyObject *__pyx_n_s_st_neuronname;
static PyObject *__pyx_n_s_st_nname;
static PyObject *__pyx_n_s_st_nodeid;
static PyObject *__pyx_n_s_st_normName;
static PyObject *__pyx_n_s_st_num;
static PyObject *__pyx_n_s_st_order;
static PyObject *__pyx_n_s_st_output;
static PyObject *__pyx_n_s_st_outputname;
static PyObject *__pyx_n_s_st_outputs;
static PyObject *__pyx_n_s_st_parentid;
static PyObject *__pyx_n_s_st_pi;
static PyObject *__pyx_n_s_st_project;
static PyObject *__pyx_n_s_st_q;
static PyObject *__pyx_n_s_st_rank;
static PyObject *__pyx_n_s_st_reverse;
static PyObject *__pyx_n_s_st_row;
static PyObject *__pyx_n_s_st_sigma;
static PyObject *__pyx_n_s_st_style;
static PyObject *__pyx_n_s_st_synapsename;
static PyObject *__pyx_n_s_st_version;
static PyObject *__pyx_n_s_st_weights;
static PyObject *__pyx_n_s_st_xmlns_xsi;
static PyObject *__pyx_n_s_stl_biasname;
static PyObject *__pyx_n_u_style;
static PyObject *__pyx_n_u_synapsename;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_u_version;
static PyObject *__pyx_n_u_weights;
static PyObject *__pyx_kp_u_xml_stylesheet_type_text_xsl;
static PyObject *__pyx_kp_u_xml_version_s_encoding_s;
static PyObject *__pyx_kp_u_xmlns_xsi;
static PyObject *__pyx_kp_u_xsi_noNamespaceSchemaLocation;
static PyObject *__pyx_tuple_;
/* Late includes */

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_const_st(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_const_st},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "const_st",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_1_0, __pyx_k_1_0, sizeof(__pyx_k_1_0), 0, 1, 0, 0},
  {&__pyx_kp_u_Activation_derivative_error_s_in, __pyx_k_Activation_derivative_error_s_in, sizeof(__pyx_k_Activation_derivative_error_s_in), 0, 1, 0, 0},
  {&__pyx_kp_u_Activation_error_s_in_node_s_for, __pyx_k_Activation_error_s_in_node_s_for, sizeof(__pyx_k_Activation_error_s_in_node_s_for), 0, 1, 0, 0},
  {&__pyx_kp_u_Activation_second_derivative_err, __pyx_k_Activation_second_derivative_err, sizeof(__pyx_k_Activation_second_derivative_err), 0, 1, 0, 0},
  {&__pyx_kp_u_Architecture_error_in_NODE_LAYER, __pyx_k_Architecture_error_in_NODE_LAYER, sizeof(__pyx_k_Architecture_error_in_NODE_LAYER), 0, 1, 0, 0},
  {&__pyx_kp_u_Bad_input_number, __pyx_k_Bad_input_number, sizeof(__pyx_k_Bad_input_number), 0, 1, 0, 0},
  {&__pyx_n_u_COL, __pyx_k_COL, sizeof(__pyx_k_COL), 0, 1, 0, 1},
  {&__pyx_n_u_CONFIDENCE, __pyx_k_CONFIDENCE, sizeof(__pyx_k_CONFIDENCE), 0, 1, 0, 1},
  {&__pyx_n_u_CONFLEVEL, __pyx_k_CONFLEVEL, sizeof(__pyx_k_CONFLEVEL), 0, 1, 0, 1},
  {&__pyx_n_s_ConstError, __pyx_k_ConstError, sizeof(__pyx_k_ConstError), 0, 0, 1, 1},
  {&__pyx_kp_u_Cost_compute_s_line_d_for_vcal_f, __pyx_k_Cost_compute_s_line_d_for_vcal_f, sizeof(__pyx_k_Cost_compute_s_line_d_for_vcal_f), 0, 1, 0, 0},
  {&__pyx_kp_u_Cost_function_s_unknown, __pyx_k_Cost_function_s_unknown, sizeof(__pyx_k_Cost_function_s_unknown), 0, 1, 0, 0},
  {&__pyx_n_u_DATA, __pyx_k_DATA, sizeof(__pyx_k_DATA), 0, 1, 0, 1},
  {&__pyx_kp_u_Dimension_error, __pyx_k_Dimension_error, sizeof(__pyx_k_Dimension_error), 0, 1, 0, 0},
  {&__pyx_kp_u_Empty_vector, __pyx_k_Empty_vector, sizeof(__pyx_k_Empty_vector), 0, 1, 0, 0},
  {&__pyx_kp_u_Error_in_backpropagation, __pyx_k_Error_in_backpropagation, sizeof(__pyx_k_Error_in_backpropagation), 0, 1, 0, 0},
  {&__pyx_kp_u_H_d__d, __pyx_k_H_d__d, sizeof(__pyx_k_H_d__d), 0, 1, 0, 0},
  {&__pyx_kp_u_IN__d, __pyx_k_IN__d, sizeof(__pyx_k_IN__d), 0, 1, 0, 0},
  {&__pyx_kp_u_ISO_8859_1, __pyx_k_ISO_8859_1, sizeof(__pyx_k_ISO_8859_1), 0, 1, 0, 0},
  {&__pyx_n_u_ITEM, __pyx_k_ITEM, sizeof(__pyx_k_ITEM), 0, 1, 0, 1},
  {&__pyx_kp_u_Index_Error_Should_be_d_d_d, __pyx_k_Index_Error_Should_be_d_d_d, sizeof(__pyx_k_Index_Error_Should_be_d_d_d), 0, 1, 0, 0},
  {&__pyx_n_u_LAYER, __pyx_k_LAYER, sizeof(__pyx_k_LAYER), 0, 1, 0, 1},
  {&__pyx_n_u_LINK, __pyx_k_LINK, sizeof(__pyx_k_LINK), 0, 1, 0, 1},
  {&__pyx_n_u_MODEL, __pyx_k_MODEL, sizeof(__pyx_k_MODEL), 0, 1, 0, 1},
  {&__pyx_n_u_MU, __pyx_k_MU, sizeof(__pyx_k_MU), 0, 1, 0, 1},
  {&__pyx_n_u_MULTIMODEL, __pyx_k_MULTIMODEL, sizeof(__pyx_k_MULTIMODEL), 0, 1, 0, 1},
  {&__pyx_n_u_NETWORK, __pyx_k_NETWORK, sizeof(__pyx_k_NETWORK), 0, 1, 0, 1},
  {&__pyx_n_u_NODE, __pyx_k_NODE, sizeof(__pyx_k_NODE), 0, 1, 0, 1},
  {&__pyx_n_u_NOISEVAR, __pyx_k_NOISEVAR, sizeof(__pyx_k_NOISEVAR), 0, 1, 0, 1},
  {&__pyx_n_u_NORMALIZER, __pyx_k_NORMALIZER, sizeof(__pyx_k_NORMALIZER), 0, 1, 0, 1},
  {&__pyx_kp_u_N__s, __pyx_k_N__s, sizeof(__pyx_k_N__s), 0, 1, 0, 0},
  {&__pyx_kp_u_Need_at_least_a_function_name, __pyx_k_Need_at_least_a_function_name, sizeof(__pyx_k_Need_at_least_a_function_name), 0, 1, 0, 0},
  {&__pyx_n_u_Neuron, __pyx_k_Neuron, sizeof(__pyx_k_Neuron), 0, 1, 0, 1},
  {&__pyx_n_u_NeuronPi, __pyx_k_NeuronPi, sizeof(__pyx_k_NeuronPi), 0, 1, 0, 1},
  {&__pyx_n_u_NeuronSigma, __pyx_k_NeuronSigma, sizeof(__pyx_k_NeuronSigma), 0, 1, 0, 1},
  {&__pyx_kp_u_No_Model_in_the_Driver, __pyx_k_No_Model_in_the_Driver, sizeof(__pyx_k_No_Model_in_the_Driver), 0, 1, 0, 0},
  {&__pyx_kp_u_OUT__d, __pyx_k_OUT__d, sizeof(__pyx_k_OUT__d), 0, 1, 0, 0},
  {&__pyx_n_u_PRESS, __pyx_k_PRESS, sizeof(__pyx_k_PRESS), 0, 1, 0, 1},
  {&__pyx_n_u_REAL, __pyx_k_REAL, sizeof(__pyx_k_REAL), 0, 1, 0, 1},
  {&__pyx_n_u_STANDARD_DEVIATION, __pyx_k_STANDARD_DEVIATION, sizeof(__pyx_k_STANDARD_DEVIATION), 0, 1, 0, 1},
  {&__pyx_n_u_STUDENT, __pyx_k_STUDENT, sizeof(__pyx_k_STUDENT), 0, 1, 0, 1},
  {&__pyx_n_u_STUDENT95, __pyx_k_STUDENT95, sizeof(__pyx_k_STUDENT95), 0, 1, 0, 1},
  {&__pyx_kp_u_Sorry_the_cost_function_is_unkno, __pyx_k_Sorry_the_cost_function_is_unkno, sizeof(__pyx_k_Sorry_the_cost_function_is_unkno), 0, 1, 0, 0},
  {&__pyx_kp_u_Synapse_linking_error, __pyx_k_Synapse_linking_error, sizeof(__pyx_k_Synapse_linking_error), 0, 1, 0, 0},
  {&__pyx_kp_u_Synapse_reading_Error, __pyx_k_Synapse_reading_Error, sizeof(__pyx_k_Synapse_reading_Error), 0, 1, 0, 0},
  {&__pyx_n_u_TRAINCOST, __pyx_k_TRAINCOST, sizeof(__pyx_k_TRAINCOST), 0, 1, 0, 1},
  {&__pyx_kp_u_Train_Error_code_d, __pyx_k_Train_Error_code_d, sizeof(__pyx_k_Train_Error_code_d), 0, 1, 0, 0},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_n_u_VALUE, __pyx_k_VALUE, sizeof(__pyx_k_VALUE), 0, 1, 0, 1},
  {&__pyx_n_u_WEIGHTS, __pyx_k_WEIGHTS, sizeof(__pyx_k_WEIGHTS), 0, 1, 0, 1},
  {&__pyx_kp_u_W__d, __pyx_k_W__d, sizeof(__pyx_k_W__d), 0, 1, 0, 0},
  {&__pyx_kp_u_Weight_reading_Error_in_MultiMod, __pyx_k_Weight_reading_Error_in_MultiMod, sizeof(__pyx_k_Weight_reading_Error_in_MultiMod), 0, 1, 0, 0},
  {&__pyx_kp_u_Weight_writing_Error_in_MultiMod, __pyx_k_Weight_writing_Error_in_MultiMod, sizeof(__pyx_k_Weight_writing_Error_in_MultiMod), 0, 1, 0, 0},
  {&__pyx_n_u_ZTZ, __pyx_k_ZTZ, sizeof(__pyx_k_ZTZ), 0, 1, 0, 1},
  {&__pyx_n_u_activ, __pyx_k_activ, sizeof(__pyx_k_activ), 0, 1, 0, 1},
  {&__pyx_n_u_biais, __pyx_k_biais, sizeof(__pyx_k_biais), 0, 1, 0, 1},
  {&__pyx_n_u_bias, __pyx_k_bias, sizeof(__pyx_k_bias), 0, 1, 0, 1},
  {&__pyx_kp_u_can_t_delete_item_from_fixed_vec, __pyx_k_can_t_delete_item_from_fixed_vec, sizeof(__pyx_k_can_t_delete_item_from_fixed_vec), 0, 1, 0, 0},
  {&__pyx_n_u_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 1, 0, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_u_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 1, 0, 1},
  {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {&__pyx_n_u_function, __pyx_k_function, sizeof(__pyx_k_function), 0, 1, 0, 1},
  {&__pyx_kp_u_http_www_netral_com_public_xml_x, __pyx_k_http_www_netral_com_public_xml_x, sizeof(__pyx_k_http_www_netral_com_public_xml_x), 0, 1, 0, 0},
  {&__pyx_kp_u_http_www_w3_org_2001_XMLSchema_i, __pyx_k_http_www_w3_org_2001_XMLSchema_i, sizeof(__pyx_k_http_www_w3_org_2001_XMLSchema_i), 0, 1, 0, 0},
  {&__pyx_n_u_inputname, __pyx_k_inputname, sizeof(__pyx_k_inputname), 0, 1, 0, 1},
  {&__pyx_n_u_inputs, __pyx_k_inputs, sizeof(__pyx_k_inputs), 0, 1, 0, 1},
  {&__pyx_n_u_jrank, __pyx_k_jrank, sizeof(__pyx_k_jrank), 0, 1, 0, 1},
  {&__pyx_n_u_kind, __pyx_k_kind, sizeof(__pyx_k_kind), 0, 1, 0, 1},
  {&__pyx_n_u_layer, __pyx_k_layer, sizeof(__pyx_k_layer), 0, 1, 0, 1},
  {&__pyx_n_u_linkid, __pyx_k_linkid, sizeof(__pyx_k_linkid), 0, 1, 0, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
  {&__pyx_n_s_metaphor_monal_util_const_st, __pyx_k_metaphor_monal_util_const_st, sizeof(__pyx_k_metaphor_monal_util_const_st), 0, 0, 1, 1},
  {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {&__pyx_n_u_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 1, 0, 1},
  {&__pyx_n_u_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 1, 0, 1},
  {&__pyx_kp_u_need_a_path_to_model_file_or_a_n, __pyx_k_need_a_path_to_model_file_or_a_n, sizeof(__pyx_k_need_a_path_to_model_file_or_a_n), 0, 1, 0, 0},
  {&__pyx_kp_u_negative_number_of_inputs_output, __pyx_k_negative_number_of_inputs_output, sizeof(__pyx_k_negative_number_of_inputs_output), 0, 1, 0, 0},
  {&__pyx_n_u_neuronname, __pyx_k_neuronname, sizeof(__pyx_k_neuronname), 0, 1, 0, 1},
  {&__pyx_n_u_nname, __pyx_k_nname, sizeof(__pyx_k_nname), 0, 1, 0, 1},
  {&__pyx_n_u_nodeid, __pyx_k_nodeid, sizeof(__pyx_k_nodeid), 0, 1, 0, 1},
  {&__pyx_n_u_num, __pyx_k_num, sizeof(__pyx_k_num), 0, 1, 0, 1},
  {&__pyx_n_u_order, __pyx_k_order, sizeof(__pyx_k_order), 0, 1, 0, 1},
  {&__pyx_n_u_output, __pyx_k_output, sizeof(__pyx_k_output), 0, 1, 0, 1},
  {&__pyx_n_u_outputname, __pyx_k_outputname, sizeof(__pyx_k_outputname), 0, 1, 0, 1},
  {&__pyx_n_u_outputs, __pyx_k_outputs, sizeof(__pyx_k_outputs), 0, 1, 0, 1},
  {&__pyx_n_u_parentid, __pyx_k_parentid, sizeof(__pyx_k_parentid), 0, 1, 0, 1},
  {&__pyx_n_u_pi, __pyx_k_pi, sizeof(__pyx_k_pi), 0, 1, 0, 1},
  {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
  {&__pyx_n_u_project, __pyx_k_project, sizeof(__pyx_k_project), 0, 1, 0, 1},
  {&__pyx_n_u_q, __pyx_k_q, sizeof(__pyx_k_q), 0, 1, 0, 1},
  {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
  {&__pyx_n_u_rank, __pyx_k_rank, sizeof(__pyx_k_rank), 0, 1, 0, 1},
  {&__pyx_n_u_reverse, __pyx_k_reverse, sizeof(__pyx_k_reverse), 0, 1, 0, 1},
  {&__pyx_n_u_row, __pyx_k_row, sizeof(__pyx_k_row), 0, 1, 0, 1},
  {&__pyx_kp_u_s_Index_Error_Should_be_d_d_d, __pyx_k_s_Index_Error_Should_be_d_d_d, sizeof(__pyx_k_s_Index_Error_Should_be_d_d_d), 0, 1, 0, 0},
  {&__pyx_n_u_sigma, __pyx_k_sigma, sizeof(__pyx_k_sigma), 0, 1, 0, 1},
  {&__pyx_n_s_st_ActivationDerivative2Error, __pyx_k_st_ActivationDerivative2Error, sizeof(__pyx_k_st_ActivationDerivative2Error), 0, 0, 1, 1},
  {&__pyx_n_s_st_ActivationDerivativeError, __pyx_k_st_ActivationDerivativeError, sizeof(__pyx_k_st_ActivationDerivativeError), 0, 0, 1, 1},
  {&__pyx_n_s_st_ActivationError, __pyx_k_st_ActivationError, sizeof(__pyx_k_st_ActivationError), 0, 0, 1, 1},
  {&__pyx_n_s_st_ArchLayerErr, __pyx_k_st_ArchLayerErr, sizeof(__pyx_k_st_ArchLayerErr), 0, 0, 1, 1},
  {&__pyx_n_s_st_BackPropErr, __pyx_k_st_BackPropErr, sizeof(__pyx_k_st_BackPropErr), 0, 0, 1, 1},
  {&__pyx_n_s_st_BadInputNb, __pyx_k_st_BadInputNb, sizeof(__pyx_k_st_BadInputNb), 0, 0, 1, 1},
  {&__pyx_n_s_st_COL, __pyx_k_st_COL, sizeof(__pyx_k_st_COL), 0, 0, 1, 1},
  {&__pyx_n_s_st_CONFIDENCE, __pyx_k_st_CONFIDENCE, sizeof(__pyx_k_st_CONFIDENCE), 0, 0, 1, 1},
  {&__pyx_n_s_st_CONFLEVEL, __pyx_k_st_CONFLEVEL, sizeof(__pyx_k_st_CONFLEVEL), 0, 0, 1, 1},
  {&__pyx_n_s_st_CantDelVecErr, __pyx_k_st_CantDelVecErr, sizeof(__pyx_k_st_CantDelVecErr), 0, 0, 1, 1},
  {&__pyx_n_s_st_CostComputeDisp, __pyx_k_st_CostComputeDisp, sizeof(__pyx_k_st_CostComputeDisp), 0, 0, 1, 1},
  {&__pyx_n_s_st_CostFuncUnknown, __pyx_k_st_CostFuncUnknown, sizeof(__pyx_k_st_CostFuncUnknown), 0, 0, 1, 1},
  {&__pyx_n_s_st_DATA, __pyx_k_st_DATA, sizeof(__pyx_k_st_DATA), 0, 0, 1, 1},
  {&__pyx_n_s_st_DiErr, __pyx_k_st_DiErr, sizeof(__pyx_k_st_DiErr), 0, 0, 1, 1},
  {&__pyx_n_s_st_EmptVecErr, __pyx_k_st_EmptVecErr, sizeof(__pyx_k_st_EmptVecErr), 0, 0, 1, 1},
  {&__pyx_n_s_st_Encoding, __pyx_k_st_Encoding, sizeof(__pyx_k_st_Encoding), 0, 0, 1, 1},
  {&__pyx_n_s_st_HIDdefault, __pyx_k_st_HIDdefault, sizeof(__pyx_k_st_HIDdefault), 0, 0, 1, 1},
  {&__pyx_n_s_st_INdefault, __pyx_k_st_INdefault, sizeof(__pyx_k_st_INdefault), 0, 0, 1, 1},
  {&__pyx_n_s_st_ITEM, __pyx_k_st_ITEM, sizeof(__pyx_k_st_ITEM), 0, 0, 1, 1},
  {&__pyx_n_s_st_IndexErrorWithLimits, __pyx_k_st_IndexErrorWithLimits, sizeof(__pyx_k_st_IndexErrorWithLimits), 0, 0, 1, 1},
  {&__pyx_n_s_st_LAYER, __pyx_k_st_LAYER, sizeof(__pyx_k_st_LAYER), 0, 0, 1, 1},
  {&__pyx_n_s_st_LINK, __pyx_k_st_LINK, sizeof(__pyx_k_st_LINK), 0, 0, 1, 1},
  {&__pyx_n_s_st_MODEL, __pyx_k_st_MODEL, sizeof(__pyx_k_st_MODEL), 0, 0, 1, 1},
  {&__pyx_n_s_st_MU, __pyx_k_st_MU, sizeof(__pyx_k_st_MU), 0, 0, 1, 1},
  {&__pyx_n_s_st_MULTIMODEL, __pyx_k_st_MULTIMODEL, sizeof(__pyx_k_st_MULTIMODEL), 0, 0, 1, 1},
  {&__pyx_n_s_st_ModelList, __pyx_k_st_ModelList, sizeof(__pyx_k_st_ModelList), 0, 0, 1, 1},
  {&__pyx_n_s_st_ModelURL, __pyx_k_st_ModelURL, sizeof(__pyx_k_st_ModelURL), 0, 0, 1, 1},
  {&__pyx_n_s_st_NETWORK, __pyx_k_st_NETWORK, sizeof(__pyx_k_st_NETWORK), 0, 0, 1, 1},
  {&__pyx_n_s_st_NODE, __pyx_k_st_NODE, sizeof(__pyx_k_st_NODE), 0, 0, 1, 1},
  {&__pyx_n_s_st_NOISEVAR, __pyx_k_st_NOISEVAR, sizeof(__pyx_k_st_NOISEVAR), 0, 0, 1, 1},
  {&__pyx_n_s_st_NORMALIZER, __pyx_k_st_NORMALIZER, sizeof(__pyx_k_st_NORMALIZER), 0, 0, 1, 1},
  {&__pyx_n_s_st_NamedIndexErrorWithLimits, __pyx_k_st_NamedIndexErrorWithLimits, sizeof(__pyx_k_st_NamedIndexErrorWithLimits), 0, 0, 1, 1},
  {&__pyx_n_s_st_NeedFunctionName, __pyx_k_st_NeedFunctionName, sizeof(__pyx_k_st_NeedFunctionName), 0, 0, 1, 1},
  {&__pyx_n_s_st_NeedNetDef, __pyx_k_st_NeedNetDef, sizeof(__pyx_k_st_NeedNetDef), 0, 0, 1, 1},
  {&__pyx_n_s_st_Neuron, __pyx_k_st_Neuron, sizeof(__pyx_k_st_Neuron), 0, 0, 1, 1},
  {&__pyx_n_s_st_NeuronPi, __pyx_k_st_NeuronPi, sizeof(__pyx_k_st_NeuronPi), 0, 0, 1, 1},
  {&__pyx_n_s_st_NeuronSigma, __pyx_k_st_NeuronSigma, sizeof(__pyx_k_st_NeuronSigma), 0, 0, 1, 1},
  {&__pyx_n_s_st_NoCostFct, __pyx_k_st_NoCostFct, sizeof(__pyx_k_st_NoCostFct), 0, 0, 1, 1},
  {&__pyx_n_s_st_NoModelErr, __pyx_k_st_NoModelErr, sizeof(__pyx_k_st_NoModelErr), 0, 0, 1, 1},
  {&__pyx_n_s_st_NodeList, __pyx_k_st_NodeList, sizeof(__pyx_k_st_NodeList), 0, 0, 1, 1},
  {&__pyx_n_s_st_OUTdefault, __pyx_k_st_OUTdefault, sizeof(__pyx_k_st_OUTdefault), 0, 0, 1, 1},
  {&__pyx_n_s_st_PRESS, __pyx_k_st_PRESS, sizeof(__pyx_k_st_PRESS), 0, 0, 1, 1},
  {&__pyx_n_s_st_REAL, __pyx_k_st_REAL, sizeof(__pyx_k_st_REAL), 0, 0, 1, 1},
  {&__pyx_n_s_st_STANDARD_DEVIATION, __pyx_k_st_STANDARD_DEVIATION, sizeof(__pyx_k_st_STANDARD_DEVIATION), 0, 0, 1, 1},
  {&__pyx_n_s_st_STUDENT, __pyx_k_st_STUDENT, sizeof(__pyx_k_st_STUDENT), 0, 0, 1, 1},
  {&__pyx_n_s_st_STUDENT95, __pyx_k_st_STUDENT95, sizeof(__pyx_k_st_STUDENT95), 0, 0, 1, 1},
  {&__pyx_n_s_st_SynLinkErr, __pyx_k_st_SynLinkErr, sizeof(__pyx_k_st_SynLinkErr), 0, 0, 1, 1},
  {&__pyx_n_s_st_SynReadErr, __pyx_k_st_SynReadErr, sizeof(__pyx_k_st_SynReadErr), 0, 0, 1, 1},
  {&__pyx_n_s_st_TRAINCOST, __pyx_k_st_TRAINCOST, sizeof(__pyx_k_st_TRAINCOST), 0, 0, 1, 1},
  {&__pyx_n_s_st_TrainErrorCode, __pyx_k_st_TrainErrorCode, sizeof(__pyx_k_st_TrainErrorCode), 0, 0, 1, 1},
  {&__pyx_n_s_st_VALUE, __pyx_k_st_VALUE, sizeof(__pyx_k_st_VALUE), 0, 0, 1, 1},
  {&__pyx_n_s_st_WEIGHTS, __pyx_k_st_WEIGHTS, sizeof(__pyx_k_st_WEIGHTS), 0, 0, 1, 1},
  {&__pyx_n_s_st_WEIGHTdefault, __pyx_k_st_WEIGHTdefault, sizeof(__pyx_k_st_WEIGHTdefault), 0, 0, 1, 1},
  {&__pyx_n_s_st_WeightReadMErr, __pyx_k_st_WeightReadMErr, sizeof(__pyx_k_st_WeightReadMErr), 0, 0, 1, 1},
  {&__pyx_n_s_st_WeightWritMErr, __pyx_k_st_WeightWritMErr, sizeof(__pyx_k_st_WeightWritMErr), 0, 0, 1, 1},
  {&__pyx_n_s_st_XMLEncoding, __pyx_k_st_XMLEncoding, sizeof(__pyx_k_st_XMLEncoding), 0, 0, 1, 1},
  {&__pyx_n_s_st_XMLHeader, __pyx_k_st_XMLHeader, sizeof(__pyx_k_st_XMLHeader), 0, 0, 1, 1},
  {&__pyx_n_s_st_XMLSchema, __pyx_k_st_XMLSchema, sizeof(__pyx_k_st_XMLSchema), 0, 0, 1, 1},
  {&__pyx_n_s_st_XMLSchemaLoc, __pyx_k_st_XMLSchemaLoc, sizeof(__pyx_k_st_XMLSchemaLoc), 0, 0, 1, 1},
  {&__pyx_n_s_st_XMLStyleSheet, __pyx_k_st_XMLStyleSheet, sizeof(__pyx_k_st_XMLStyleSheet), 0, 0, 1, 1},
  {&__pyx_n_s_st_XMLVersion, __pyx_k_st_XMLVersion, sizeof(__pyx_k_st_XMLVersion), 0, 0, 1, 1},
  {&__pyx_n_s_st_ZTZ, __pyx_k_st_ZTZ, sizeof(__pyx_k_st_ZTZ), 0, 0, 1, 1},
  {&__pyx_n_s_st_activ, __pyx_k_st_activ, sizeof(__pyx_k_st_activ), 0, 0, 1, 1},
  {&__pyx_n_s_st_bias, __pyx_k_st_bias, sizeof(__pyx_k_st_bias), 0, 0, 1, 1},
  {&__pyx_n_s_st_class, __pyx_k_st_class, sizeof(__pyx_k_st_class), 0, 0, 1, 1},
  {&__pyx_n_s_st_count, __pyx_k_st_count, sizeof(__pyx_k_st_count), 0, 0, 1, 1},
  {&__pyx_n_s_st_function, __pyx_k_st_function, sizeof(__pyx_k_st_function), 0, 0, 1, 1},
  {&__pyx_n_s_st_inputname, __pyx_k_st_inputname, sizeof(__pyx_k_st_inputname), 0, 0, 1, 1},
  {&__pyx_n_s_st_inputs, __pyx_k_st_inputs, sizeof(__pyx_k_st_inputs), 0, 0, 1, 1},
  {&__pyx_n_s_st_jrank, __pyx_k_st_jrank, sizeof(__pyx_k_st_jrank), 0, 0, 1, 1},
  {&__pyx_n_s_st_kind, __pyx_k_st_kind, sizeof(__pyx_k_st_kind), 0, 0, 1, 1},
  {&__pyx_n_s_st_layer, __pyx_k_st_layer, sizeof(__pyx_k_st_layer), 0, 0, 1, 1},
  {&__pyx_n_s_st_linkid, __pyx_k_st_linkid, sizeof(__pyx_k_st_linkid), 0, 0, 1, 1},
  {&__pyx_n_s_st_n, __pyx_k_st_n, sizeof(__pyx_k_st_n), 0, 0, 1, 1},
  {&__pyx_n_s_st_name, __pyx_k_st_name, sizeof(__pyx_k_st_name), 0, 0, 1, 1},
  {&__pyx_n_s_st_negativeInput, __pyx_k_st_negativeInput, sizeof(__pyx_k_st_negativeInput), 0, 0, 1, 1},
  {&__pyx_n_s_st_neuronname, __pyx_k_st_neuronname, sizeof(__pyx_k_st_neuronname), 0, 0, 1, 1},
  {&__pyx_n_s_st_nname, __pyx_k_st_nname, sizeof(__pyx_k_st_nname), 0, 0, 1, 1},
  {&__pyx_n_s_st_nodeid, __pyx_k_st_nodeid, sizeof(__pyx_k_st_nodeid), 0, 0, 1, 1},
  {&__pyx_n_s_st_normName, __pyx_k_st_normName, sizeof(__pyx_k_st_normName), 0, 0, 1, 1},
  {&__pyx_n_s_st_num, __pyx_k_st_num, sizeof(__pyx_k_st_num), 0, 0, 1, 1},
  {&__pyx_n_s_st_order, __pyx_k_st_order, sizeof(__pyx_k_st_order), 0, 0, 1, 1},
  {&__pyx_n_s_st_output, __pyx_k_st_output, sizeof(__pyx_k_st_output), 0, 0, 1, 1},
  {&__pyx_n_s_st_outputname, __pyx_k_st_outputname, sizeof(__pyx_k_st_outputname), 0, 0, 1, 1},
  {&__pyx_n_s_st_outputs, __pyx_k_st_outputs, sizeof(__pyx_k_st_outputs), 0, 0, 1, 1},
  {&__pyx_n_s_st_parentid, __pyx_k_st_parentid, sizeof(__pyx_k_st_parentid), 0, 0, 1, 1},
  {&__pyx_n_s_st_pi, __pyx_k_st_pi, sizeof(__pyx_k_st_pi), 0, 0, 1, 1},
  {&__pyx_n_s_st_project, __pyx_k_st_project, sizeof(__pyx_k_st_project), 0, 0, 1, 1},
  {&__pyx_n_s_st_q, __pyx_k_st_q, sizeof(__pyx_k_st_q), 0, 0, 1, 1},
  {&__pyx_n_s_st_rank, __pyx_k_st_rank, sizeof(__pyx_k_st_rank), 0, 0, 1, 1},
  {&__pyx_n_s_st_reverse, __pyx_k_st_reverse, sizeof(__pyx_k_st_reverse), 0, 0, 1, 1},
  {&__pyx_n_s_st_row, __pyx_k_st_row, sizeof(__pyx_k_st_row), 0, 0, 1, 1},
  {&__pyx_n_s_st_sigma, __pyx_k_st_sigma, sizeof(__pyx_k_st_sigma), 0, 0, 1, 1},
  {&__pyx_n_s_st_style, __pyx_k_st_style, sizeof(__pyx_k_st_style), 0, 0, 1, 1},
  {&__pyx_n_s_st_synapsename, __pyx_k_st_synapsename, sizeof(__pyx_k_st_synapsename), 0, 0, 1, 1},
  {&__pyx_n_s_st_version, __pyx_k_st_version, sizeof(__pyx_k_st_version), 0, 0, 1, 1},
  {&__pyx_n_s_st_weights, __pyx_k_st_weights, sizeof(__pyx_k_st_weights), 0, 0, 1, 1},
  {&__pyx_n_s_st_xmlns_xsi, __pyx_k_st_xmlns_xsi, sizeof(__pyx_k_st_xmlns_xsi), 0, 0, 1, 1},
  {&__pyx_n_s_stl_biasname, __pyx_k_stl_biasname, sizeof(__pyx_k_stl_biasname), 0, 0, 1, 1},
  {&__pyx_n_u_style, __pyx_k_style, sizeof(__pyx_k_style), 0, 1, 0, 1},
  {&__pyx_n_u_synapsename, __pyx_k_synapsename, sizeof(__pyx_k_synapsename), 0, 1, 0, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_u_version, __pyx_k_version, sizeof(__pyx_k_version), 0, 1, 0, 1},
  {&__pyx_n_u_weights, __pyx_k_weights, sizeof(__pyx_k_weights), 0, 1, 0, 1},
  {&__pyx_kp_u_xml_stylesheet_type_text_xsl, __pyx_k_xml_stylesheet_type_text_xsl, sizeof(__pyx_k_xml_stylesheet_type_text_xsl), 0, 1, 0, 0},
  {&__pyx_kp_u_xml_version_s_encoding_s, __pyx_k_xml_version_s_encoding_s, sizeof(__pyx_k_xml_version_s_encoding_s), 0, 1, 0, 0},
  {&__pyx_kp_u_xmlns_xsi, __pyx_k_xmlns_xsi, sizeof(__pyx_k_xmlns_xsi), 0, 1, 0, 0},
  {&__pyx_kp_u_xsi_noNamespaceSchemaLocation, __pyx_k_xsi_noNamespaceSchemaLocation, sizeof(__pyx_k_xsi_noNamespaceSchemaLocation), 0, 1, 0, 0},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(0, 131, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "metaphor/monal/util/const_st.py":131
 * st_XMLEncoding = "ISO-8859-1"
 * 
 * class ConstError(TypeError): pass             # <<<<<<<<<<<<<<
 * 
 * #def __setattr__(self, name, value):
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_builtin_TypeError); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_modinit_global_init_code(void); /*proto*/
static int __Pyx_modinit_variable_export_code(void); /*proto*/
static int __Pyx_modinit_function_export_code(void); /*proto*/
static int __Pyx_modinit_type_init_code(void); /*proto*/
static int __Pyx_modinit_type_import_code(void); /*proto*/
static int __Pyx_modinit_variable_import_code(void); /*proto*/
static int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION < 3
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC void
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#else
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (!(defined(__cplusplus)) || (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 4)))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initconst_st(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initconst_st(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_const_st(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_const_st(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        result = PyDict_SetItemString(moddict, to_name, value);
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__") < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static int __pyx_pymod_exec_const_st(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m && __pyx_m == __pyx_pyinit_module) return 0;
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_const_st(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("const_st", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_metaphor__monal__util__const_st) {
    if (PyObject_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "metaphor.monal.util.const_st")) {
      if (unlikely(PyDict_SetItemString(modules, "metaphor.monal.util.const_st", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  (void)__Pyx_modinit_type_init_code();
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "metaphor/monal/util/const_st.py":26
 * #class _const_st(object):
 * 
 * st_Encoding = 'ISO-8859-1'             # <<<<<<<<<<<<<<
 * st_DATA = 'DATA'
 * st_LAYER = 'LAYER'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_Encoding, __pyx_kp_u_ISO_8859_1) < 0) __PYX_ERR(0, 26, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":27
 * 
 * st_Encoding = 'ISO-8859-1'
 * st_DATA = 'DATA'             # <<<<<<<<<<<<<<
 * st_LAYER = 'LAYER'
 * st_NODE = 'NODE'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_DATA, __pyx_n_u_DATA) < 0) __PYX_ERR(0, 27, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":28
 * st_Encoding = 'ISO-8859-1'
 * st_DATA = 'DATA'
 * st_LAYER = 'LAYER'             # <<<<<<<<<<<<<<
 * st_NODE = 'NODE'
 * st_LINK = 'LINK'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_LAYER, __pyx_n_u_LAYER) < 0) __PYX_ERR(0, 28, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":29
 * st_DATA = 'DATA'
 * st_LAYER = 'LAYER'
 * st_NODE = 'NODE'             # <<<<<<<<<<<<<<
 * st_LINK = 'LINK'
 * st_NETWORK = 'NETWORK'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_NODE, __pyx_n_u_NODE) < 0) __PYX_ERR(0, 29, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":30
 * st_LAYER = 'LAYER'
 * st_NODE = 'NODE'
 * st_LINK = 'LINK'             # <<<<<<<<<<<<<<
 * st_NETWORK = 'NETWORK'
 * st_MULTIMODEL = 'MULTIMODEL'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_LINK, __pyx_n_u_LINK) < 0) __PYX_ERR(0, 30, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":31
 * st_NODE = 'NODE'
 * st_LINK = 'LINK'
 * st_NETWORK = 'NETWORK'             # <<<<<<<<<<<<<<
 * st_MULTIMODEL = 'MULTIMODEL'
 * st_MODEL = 'MODEL'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_NETWORK, __pyx_n_u_NETWORK) < 0) __PYX_ERR(0, 31, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":32
 * st_LINK = 'LINK'
 * st_NETWORK = 'NETWORK'
 * st_MULTIMODEL = 'MULTIMODEL'             # <<<<<<<<<<<<<<
 * st_MODEL = 'MODEL'
 * st_NORMALIZER = 'NORMALIZER'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_MULTIMODEL, __pyx_n_u_MULTIMODEL) < 0) __PYX_ERR(0, 32, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":33
 * st_NETWORK = 'NETWORK'
 * st_MULTIMODEL = 'MULTIMODEL'
 * st_MODEL = 'MODEL'             # <<<<<<<<<<<<<<
 * st_NORMALIZER = 'NORMALIZER'
 * st_VALUE = 'VALUE'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_MODEL, __pyx_n_u_MODEL) < 0) __PYX_ERR(0, 33, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":34
 * st_MULTIMODEL = 'MULTIMODEL'
 * st_MODEL = 'MODEL'
 * st_NORMALIZER = 'NORMALIZER'             # <<<<<<<<<<<<<<
 * st_VALUE = 'VALUE'
 * st_ZTZ = 'ZTZ'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_NORMALIZER, __pyx_n_u_NORMALIZER) < 0) __PYX_ERR(0, 34, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":35
 * st_MODEL = 'MODEL'
 * st_NORMALIZER = 'NORMALIZER'
 * st_VALUE = 'VALUE'             # <<<<<<<<<<<<<<
 * st_ZTZ = 'ZTZ'
 * st_ITEM = 'ITEM'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_VALUE, __pyx_n_u_VALUE) < 0) __PYX_ERR(0, 35, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":36
 * st_NORMALIZER = 'NORMALIZER'
 * st_VALUE = 'VALUE'
 * st_ZTZ = 'ZTZ'             # <<<<<<<<<<<<<<
 * st_ITEM = 'ITEM'
 * st_COL = 'COL'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_ZTZ, __pyx_n_u_ZTZ) < 0) __PYX_ERR(0, 36, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":37
 * st_VALUE = 'VALUE'
 * st_ZTZ = 'ZTZ'
 * st_ITEM = 'ITEM'             # <<<<<<<<<<<<<<
 * st_COL = 'COL'
 * st_CONFIDENCE = 'CONFIDENCE'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_ITEM, __pyx_n_u_ITEM) < 0) __PYX_ERR(0, 37, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":38
 * st_ZTZ = 'ZTZ'
 * st_ITEM = 'ITEM'
 * st_COL = 'COL'             # <<<<<<<<<<<<<<
 * st_CONFIDENCE = 'CONFIDENCE'
 * st_PRESS = 'PRESS'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_COL, __pyx_n_u_COL) < 0) __PYX_ERR(0, 38, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":39
 * st_ITEM = 'ITEM'
 * st_COL = 'COL'
 * st_CONFIDENCE = 'CONFIDENCE'             # <<<<<<<<<<<<<<
 * st_PRESS = 'PRESS'
 * st_MU = 'MU'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_CONFIDENCE, __pyx_n_u_CONFIDENCE) < 0) __PYX_ERR(0, 39, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":40
 * st_COL = 'COL'
 * st_CONFIDENCE = 'CONFIDENCE'
 * st_PRESS = 'PRESS'             # <<<<<<<<<<<<<<
 * st_MU = 'MU'
 * st_STANDARD_DEVIATION = 'STANDARD_DEVIATION'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_PRESS, __pyx_n_u_PRESS) < 0) __PYX_ERR(0, 40, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":41
 * st_CONFIDENCE = 'CONFIDENCE'
 * st_PRESS = 'PRESS'
 * st_MU = 'MU'             # <<<<<<<<<<<<<<
 * st_STANDARD_DEVIATION = 'STANDARD_DEVIATION'
 * st_TRAINCOST = 'TRAINCOST'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_MU, __pyx_n_u_MU) < 0) __PYX_ERR(0, 41, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":42
 * st_PRESS = 'PRESS'
 * st_MU = 'MU'
 * st_STANDARD_DEVIATION = 'STANDARD_DEVIATION'             # <<<<<<<<<<<<<<
 * st_TRAINCOST = 'TRAINCOST'
 * st_NOISEVAR = 'NOISEVAR'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_STANDARD_DEVIATION, __pyx_n_u_STANDARD_DEVIATION) < 0) __PYX_ERR(0, 42, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":43
 * st_MU = 'MU'
 * st_STANDARD_DEVIATION = 'STANDARD_DEVIATION'
 * st_TRAINCOST = 'TRAINCOST'             # <<<<<<<<<<<<<<
 * st_NOISEVAR = 'NOISEVAR'
 * st_STUDENT95 = 'STUDENT95'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_TRAINCOST, __pyx_n_u_TRAINCOST) < 0) __PYX_ERR(0, 43, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":44
 * st_STANDARD_DEVIATION = 'STANDARD_DEVIATION'
 * st_TRAINCOST = 'TRAINCOST'
 * st_NOISEVAR = 'NOISEVAR'             # <<<<<<<<<<<<<<
 * st_STUDENT95 = 'STUDENT95'
 * st_STUDENT = 'STUDENT'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_NOISEVAR, __pyx_n_u_NOISEVAR) < 0) __PYX_ERR(0, 44, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":45
 * st_TRAINCOST = 'TRAINCOST'
 * st_NOISEVAR = 'NOISEVAR'
 * st_STUDENT95 = 'STUDENT95'             # <<<<<<<<<<<<<<
 * st_STUDENT = 'STUDENT'
 * st_CONFLEVEL = 'CONFLEVEL'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_STUDENT95, __pyx_n_u_STUDENT95) < 0) __PYX_ERR(0, 45, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":46
 * st_NOISEVAR = 'NOISEVAR'
 * st_STUDENT95 = 'STUDENT95'
 * st_STUDENT = 'STUDENT'             # <<<<<<<<<<<<<<
 * st_CONFLEVEL = 'CONFLEVEL'
 * st_WEIGHTS = 'WEIGHTS'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_STUDENT, __pyx_n_u_STUDENT) < 0) __PYX_ERR(0, 46, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":47
 * st_STUDENT95 = 'STUDENT95'
 * st_STUDENT = 'STUDENT'
 * st_CONFLEVEL = 'CONFLEVEL'             # <<<<<<<<<<<<<<
 * st_WEIGHTS = 'WEIGHTS'
 * st_REAL = 'REAL'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_CONFLEVEL, __pyx_n_u_CONFLEVEL) < 0) __PYX_ERR(0, 47, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":48
 * st_STUDENT = 'STUDENT'
 * st_CONFLEVEL = 'CONFLEVEL'
 * st_WEIGHTS = 'WEIGHTS'             # <<<<<<<<<<<<<<
 * st_REAL = 'REAL'
 * st_activ = "activ"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_WEIGHTS, __pyx_n_u_WEIGHTS) < 0) __PYX_ERR(0, 48, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":49
 * st_CONFLEVEL = 'CONFLEVEL'
 * st_WEIGHTS = 'WEIGHTS'
 * st_REAL = 'REAL'             # <<<<<<<<<<<<<<
 * st_activ = "activ"
 * st_layer = 'layer'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_REAL, __pyx_n_u_REAL) < 0) __PYX_ERR(0, 49, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":50
 * st_WEIGHTS = 'WEIGHTS'
 * st_REAL = 'REAL'
 * st_activ = "activ"             # <<<<<<<<<<<<<<
 * st_layer = 'layer'
 * st_class = 'class'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_activ, __pyx_n_u_activ) < 0) __PYX_ERR(0, 50, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":51
 * st_REAL = 'REAL'
 * st_activ = "activ"
 * st_layer = 'layer'             # <<<<<<<<<<<<<<
 * st_class = 'class'
 * st_Neuron = 'Neuron'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_layer, __pyx_n_u_layer) < 0) __PYX_ERR(0, 51, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":52
 * st_activ = "activ"
 * st_layer = 'layer'
 * st_class = 'class'             # <<<<<<<<<<<<<<
 * st_Neuron = 'Neuron'
 * st_NeuronPi = 'NeuronPi'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_class, __pyx_n_u_class) < 0) __PYX_ERR(0, 52, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":53
 * st_layer = 'layer'
 * st_class = 'class'
 * st_Neuron = 'Neuron'             # <<<<<<<<<<<<<<
 * st_NeuronPi = 'NeuronPi'
 * st_NeuronSigma = 'NeuronSigma'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_Neuron, __pyx_n_u_Neuron) < 0) __PYX_ERR(0, 53, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":54
 * st_class = 'class'
 * st_Neuron = 'Neuron'
 * st_NeuronPi = 'NeuronPi'             # <<<<<<<<<<<<<<
 * st_NeuronSigma = 'NeuronSigma'
 * st_pi = "pi"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_NeuronPi, __pyx_n_u_NeuronPi) < 0) __PYX_ERR(0, 54, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":55
 * st_Neuron = 'Neuron'
 * st_NeuronPi = 'NeuronPi'
 * st_NeuronSigma = 'NeuronSigma'             # <<<<<<<<<<<<<<
 * st_pi = "pi"
 * st_sigma = "sigma"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_NeuronSigma, __pyx_n_u_NeuronSigma) < 0) __PYX_ERR(0, 55, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":56
 * st_NeuronPi = 'NeuronPi'
 * st_NeuronSigma = 'NeuronSigma'
 * st_pi = "pi"             # <<<<<<<<<<<<<<
 * st_sigma = "sigma"
 * st_nname = 'nname'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_pi, __pyx_n_u_pi) < 0) __PYX_ERR(0, 56, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":57
 * st_NeuronSigma = 'NeuronSigma'
 * st_pi = "pi"
 * st_sigma = "sigma"             # <<<<<<<<<<<<<<
 * st_nname = 'nname'
 * st_num = 'num'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_sigma, __pyx_n_u_sigma) < 0) __PYX_ERR(0, 57, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":58
 * st_pi = "pi"
 * st_sigma = "sigma"
 * st_nname = 'nname'             # <<<<<<<<<<<<<<
 * st_num = 'num'
 * st_kind = "kind"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_nname, __pyx_n_u_nname) < 0) __PYX_ERR(0, 58, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":59
 * st_sigma = "sigma"
 * st_nname = 'nname'
 * st_num = 'num'             # <<<<<<<<<<<<<<
 * st_kind = "kind"
 * st_neuronname = 'neuronname'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_num, __pyx_n_u_num) < 0) __PYX_ERR(0, 59, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":60
 * st_nname = 'nname'
 * st_num = 'num'
 * st_kind = "kind"             # <<<<<<<<<<<<<<
 * st_neuronname = 'neuronname'
 * st_synapsename = 'synapsename'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_kind, __pyx_n_u_kind) < 0) __PYX_ERR(0, 60, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":61
 * st_num = 'num'
 * st_kind = "kind"
 * st_neuronname = 'neuronname'             # <<<<<<<<<<<<<<
 * st_synapsename = 'synapsename'
 * st_function = 'function'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_neuronname, __pyx_n_u_neuronname) < 0) __PYX_ERR(0, 61, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":62
 * st_kind = "kind"
 * st_neuronname = 'neuronname'
 * st_synapsename = 'synapsename'             # <<<<<<<<<<<<<<
 * st_function = 'function'
 * st_parentid = 'parentid'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_synapsename, __pyx_n_u_synapsename) < 0) __PYX_ERR(0, 62, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":63
 * st_neuronname = 'neuronname'
 * st_synapsename = 'synapsename'
 * st_function = 'function'             # <<<<<<<<<<<<<<
 * st_parentid = 'parentid'
 * st_nodeid = 'nodeid'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_function, __pyx_n_u_function) < 0) __PYX_ERR(0, 63, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":64
 * st_synapsename = 'synapsename'
 * st_function = 'function'
 * st_parentid = 'parentid'             # <<<<<<<<<<<<<<
 * st_nodeid = 'nodeid'
 * st_linkid = 'linkid'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_parentid, __pyx_n_u_parentid) < 0) __PYX_ERR(0, 64, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":65
 * st_function = 'function'
 * st_parentid = 'parentid'
 * st_nodeid = 'nodeid'             # <<<<<<<<<<<<<<
 * st_linkid = 'linkid'
 * st_style = 'style'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_nodeid, __pyx_n_u_nodeid) < 0) __PYX_ERR(0, 65, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":66
 * st_parentid = 'parentid'
 * st_nodeid = 'nodeid'
 * st_linkid = 'linkid'             # <<<<<<<<<<<<<<
 * st_style = 'style'
 * st_rank = 'rank'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_linkid, __pyx_n_u_linkid) < 0) __PYX_ERR(0, 66, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":67
 * st_nodeid = 'nodeid'
 * st_linkid = 'linkid'
 * st_style = 'style'             # <<<<<<<<<<<<<<
 * st_rank = 'rank'
 * st_jrank = 'jrank'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_style, __pyx_n_u_style) < 0) __PYX_ERR(0, 67, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":68
 * st_linkid = 'linkid'
 * st_style = 'style'
 * st_rank = 'rank'             # <<<<<<<<<<<<<<
 * st_jrank = 'jrank'
 * st_weights = 'weights'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_rank, __pyx_n_u_rank) < 0) __PYX_ERR(0, 68, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":69
 * st_style = 'style'
 * st_rank = 'rank'
 * st_jrank = 'jrank'             # <<<<<<<<<<<<<<
 * st_weights = 'weights'
 * st_inputs = 'inputs'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_jrank, __pyx_n_u_jrank) < 0) __PYX_ERR(0, 69, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":70
 * st_rank = 'rank'
 * st_jrank = 'jrank'
 * st_weights = 'weights'             # <<<<<<<<<<<<<<
 * st_inputs = 'inputs'
 * st_outputs = 'outputs'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_weights, __pyx_n_u_weights) < 0) __PYX_ERR(0, 70, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":71
 * st_jrank = 'jrank'
 * st_weights = 'weights'
 * st_inputs = 'inputs'             # <<<<<<<<<<<<<<
 * st_outputs = 'outputs'
 * st_output = 'output'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_inputs, __pyx_n_u_inputs) < 0) __PYX_ERR(0, 71, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":72
 * st_weights = 'weights'
 * st_inputs = 'inputs'
 * st_outputs = 'outputs'             # <<<<<<<<<<<<<<
 * st_output = 'output'
 * st_count = 'count'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_outputs, __pyx_n_u_outputs) < 0) __PYX_ERR(0, 72, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":73
 * st_inputs = 'inputs'
 * st_outputs = 'outputs'
 * st_output = 'output'             # <<<<<<<<<<<<<<
 * st_count = 'count'
 * st_row = 'row'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_output, __pyx_n_u_output) < 0) __PYX_ERR(0, 73, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":74
 * st_outputs = 'outputs'
 * st_output = 'output'
 * st_count = 'count'             # <<<<<<<<<<<<<<
 * st_row = 'row'
 * st_order = 'order'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_count, __pyx_n_u_count) < 0) __PYX_ERR(0, 74, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":75
 * st_output = 'output'
 * st_count = 'count'
 * st_row = 'row'             # <<<<<<<<<<<<<<
 * st_order = 'order'
 * st_version = 'version'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_row, __pyx_n_u_row) < 0) __PYX_ERR(0, 75, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":76
 * st_count = 'count'
 * st_row = 'row'
 * st_order = 'order'             # <<<<<<<<<<<<<<
 * st_version = 'version'
 * st_project = 'project'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_order, __pyx_n_u_order) < 0) __PYX_ERR(0, 76, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":77
 * st_row = 'row'
 * st_order = 'order'
 * st_version = 'version'             # <<<<<<<<<<<<<<
 * st_project = 'project'
 * st_name = 'name'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_version, __pyx_n_u_version) < 0) __PYX_ERR(0, 77, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":78
 * st_order = 'order'
 * st_version = 'version'
 * st_project = 'project'             # <<<<<<<<<<<<<<
 * st_name = 'name'
 * st_inputname = 'inputname'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_project, __pyx_n_u_project) < 0) __PYX_ERR(0, 78, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":79
 * st_version = 'version'
 * st_project = 'project'
 * st_name = 'name'             # <<<<<<<<<<<<<<
 * st_inputname = 'inputname'
 * st_outputname = 'outputname'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_name, __pyx_n_u_name) < 0) __PYX_ERR(0, 79, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":80
 * st_project = 'project'
 * st_name = 'name'
 * st_inputname = 'inputname'             # <<<<<<<<<<<<<<
 * st_outputname = 'outputname'
 * st_output = "output"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_inputname, __pyx_n_u_inputname) < 0) __PYX_ERR(0, 80, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":81
 * st_name = 'name'
 * st_inputname = 'inputname'
 * st_outputname = 'outputname'             # <<<<<<<<<<<<<<
 * st_output = "output"
 * st_n = 'n'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_outputname, __pyx_n_u_outputname) < 0) __PYX_ERR(0, 81, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":82
 * st_inputname = 'inputname'
 * st_outputname = 'outputname'
 * st_output = "output"             # <<<<<<<<<<<<<<
 * st_n = 'n'
 * st_q = 'q'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_output, __pyx_n_u_output) < 0) __PYX_ERR(0, 82, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":83
 * st_outputname = 'outputname'
 * st_output = "output"
 * st_n = 'n'             # <<<<<<<<<<<<<<
 * st_q = 'q'
 * st_reverse = 'reverse'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_n, __pyx_n_u_n) < 0) __PYX_ERR(0, 83, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":84
 * st_output = "output"
 * st_n = 'n'
 * st_q = 'q'             # <<<<<<<<<<<<<<
 * st_reverse = 'reverse'
 * st_bias = "bias"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_q, __pyx_n_u_q) < 0) __PYX_ERR(0, 84, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":85
 * st_n = 'n'
 * st_q = 'q'
 * st_reverse = 'reverse'             # <<<<<<<<<<<<<<
 * st_bias = "bias"
 * stl_biasname = ['bias', 'biais']
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_reverse, __pyx_n_u_reverse) < 0) __PYX_ERR(0, 85, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":86
 * st_q = 'q'
 * st_reverse = 'reverse'
 * st_bias = "bias"             # <<<<<<<<<<<<<<
 * stl_biasname = ['bias', 'biais']
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_bias, __pyx_n_u_bias) < 0) __PYX_ERR(0, 86, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":87
 * st_reverse = 'reverse'
 * st_bias = "bias"
 * stl_biasname = ['bias', 'biais']             # <<<<<<<<<<<<<<
 * 
 * st_ModelList = [st_MULTIMODEL, st_NETWORK, st_NORMALIZER]
 */
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_bias);
  __Pyx_GIVEREF(__pyx_n_u_bias);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_bias);
  __Pyx_INCREF(__pyx_n_u_biais);
  __Pyx_GIVEREF(__pyx_n_u_biais);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_biais);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stl_biasname, __pyx_t_1) < 0) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "metaphor/monal/util/const_st.py":89
 * stl_biasname = ['bias', 'biais']
 * 
 * st_ModelList = [st_MULTIMODEL, st_NETWORK, st_NORMALIZER]             # <<<<<<<<<<<<<<
 * st_NodeList = [st_NODE]
 * #st_NotYet = 'Not yet implemented'
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_st_MULTIMODEL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_st_NETWORK); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_st_NORMALIZER); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyList_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyList_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_4, 2, __pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_ModelList, __pyx_t_4) < 0) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "metaphor/monal/util/const_st.py":90
 * 
 * st_ModelList = [st_MULTIMODEL, st_NETWORK, st_NORMALIZER]
 * st_NodeList = [st_NODE]             # <<<<<<<<<<<<<<
 * #st_NotYet = 'Not yet implemented'
 * st_DiErr = 'Dimension error'
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_st_NODE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
  __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_NodeList, __pyx_t_3) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "metaphor/monal/util/const_st.py":92
 * st_NodeList = [st_NODE]
 * #st_NotYet = 'Not yet implemented'
 * st_DiErr = 'Dimension error'             # <<<<<<<<<<<<<<
 * st_SynReadErr = 'Synapse reading Error'
 * st_SynLinkErr = 'Synapse linking error'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_DiErr, __pyx_kp_u_Dimension_error) < 0) __PYX_ERR(0, 92, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":93
 * #st_NotYet = 'Not yet implemented'
 * st_DiErr = 'Dimension error'
 * st_SynReadErr = 'Synapse reading Error'             # <<<<<<<<<<<<<<
 * st_SynLinkErr = 'Synapse linking error'
 * st_ArchLayerErr = 'Architecture error in NODE/LAYER parentship'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_SynReadErr, __pyx_kp_u_Synapse_reading_Error) < 0) __PYX_ERR(0, 93, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":94
 * st_DiErr = 'Dimension error'
 * st_SynReadErr = 'Synapse reading Error'
 * st_SynLinkErr = 'Synapse linking error'             # <<<<<<<<<<<<<<
 * st_ArchLayerErr = 'Architecture error in NODE/LAYER parentship'
 * st_EmptVecErr = 'Empty vector'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_SynLinkErr, __pyx_kp_u_Synapse_linking_error) < 0) __PYX_ERR(0, 94, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":95
 * st_SynReadErr = 'Synapse reading Error'
 * st_SynLinkErr = 'Synapse linking error'
 * st_ArchLayerErr = 'Architecture error in NODE/LAYER parentship'             # <<<<<<<<<<<<<<
 * st_EmptVecErr = 'Empty vector'
 * st_CantDelVecErr = "can't delete item from fixed vector"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_ArchLayerErr, __pyx_kp_u_Architecture_error_in_NODE_LAYER) < 0) __PYX_ERR(0, 95, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":96
 * st_SynLinkErr = 'Synapse linking error'
 * st_ArchLayerErr = 'Architecture error in NODE/LAYER parentship'
 * st_EmptVecErr = 'Empty vector'             # <<<<<<<<<<<<<<
 * st_CantDelVecErr = "can't delete item from fixed vector"
 * st_BackPropErr = 'Error in backpropagation'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_EmptVecErr, __pyx_kp_u_Empty_vector) < 0) __PYX_ERR(0, 96, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":97
 * st_ArchLayerErr = 'Architecture error in NODE/LAYER parentship'
 * st_EmptVecErr = 'Empty vector'
 * st_CantDelVecErr = "can't delete item from fixed vector"             # <<<<<<<<<<<<<<
 * st_BackPropErr = 'Error in backpropagation'
 * st_TrainErrorCode = "Train Error code = %d"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_CantDelVecErr, __pyx_kp_u_can_t_delete_item_from_fixed_vec) < 0) __PYX_ERR(0, 97, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":98
 * st_EmptVecErr = 'Empty vector'
 * st_CantDelVecErr = "can't delete item from fixed vector"
 * st_BackPropErr = 'Error in backpropagation'             # <<<<<<<<<<<<<<
 * st_TrainErrorCode = "Train Error code = %d"
 * st_WeightReadMErr = 'Weight reading Error in MultiModel'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_BackPropErr, __pyx_kp_u_Error_in_backpropagation) < 0) __PYX_ERR(0, 98, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":99
 * st_CantDelVecErr = "can't delete item from fixed vector"
 * st_BackPropErr = 'Error in backpropagation'
 * st_TrainErrorCode = "Train Error code = %d"             # <<<<<<<<<<<<<<
 * st_WeightReadMErr = 'Weight reading Error in MultiModel'
 * st_WeightWritMErr = 'Weight writing Error in MultiModel'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_TrainErrorCode, __pyx_kp_u_Train_Error_code_d) < 0) __PYX_ERR(0, 99, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":100
 * st_BackPropErr = 'Error in backpropagation'
 * st_TrainErrorCode = "Train Error code = %d"
 * st_WeightReadMErr = 'Weight reading Error in MultiModel'             # <<<<<<<<<<<<<<
 * st_WeightWritMErr = 'Weight writing Error in MultiModel'
 * st_NoModelErr = 'No Model in the Driver'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_WeightReadMErr, __pyx_kp_u_Weight_reading_Error_in_MultiMod) < 0) __PYX_ERR(0, 100, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":101
 * st_TrainErrorCode = "Train Error code = %d"
 * st_WeightReadMErr = 'Weight reading Error in MultiModel'
 * st_WeightWritMErr = 'Weight writing Error in MultiModel'             # <<<<<<<<<<<<<<
 * st_NoModelErr = 'No Model in the Driver'
 * st_NoCostFct = 'Sorry, the cost function is unknown'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_WeightWritMErr, __pyx_kp_u_Weight_writing_Error_in_MultiMod) < 0) __PYX_ERR(0, 101, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":102
 * st_WeightReadMErr = 'Weight reading Error in MultiModel'
 * st_WeightWritMErr = 'Weight writing Error in MultiModel'
 * st_NoModelErr = 'No Model in the Driver'             # <<<<<<<<<<<<<<
 * st_NoCostFct = 'Sorry, the cost function is unknown'
 * st_ActivationError = "Activation error %s in node='%s' for activation='%s', potential=%f"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_NoModelErr, __pyx_kp_u_No_Model_in_the_Driver) < 0) __PYX_ERR(0, 102, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":103
 * st_WeightWritMErr = 'Weight writing Error in MultiModel'
 * st_NoModelErr = 'No Model in the Driver'
 * st_NoCostFct = 'Sorry, the cost function is unknown'             # <<<<<<<<<<<<<<
 * st_ActivationError = "Activation error %s in node='%s' for activation='%s', potential=%f"
 * st_ActivationDerivativeError = "Activation derivative error %s in node='%s' for activation='%s', potential=%f"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_NoCostFct, __pyx_kp_u_Sorry_the_cost_function_is_unkno) < 0) __PYX_ERR(0, 103, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":104
 * st_NoModelErr = 'No Model in the Driver'
 * st_NoCostFct = 'Sorry, the cost function is unknown'
 * st_ActivationError = "Activation error %s in node='%s' for activation='%s', potential=%f"             # <<<<<<<<<<<<<<
 * st_ActivationDerivativeError = "Activation derivative error %s in node='%s' for activation='%s', potential=%f"
 * st_ActivationDerivative2Error = "Activation second derivative error %s in node='%s' for activation='%s', potential=%f, derivative=%f"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_ActivationError, __pyx_kp_u_Activation_error_s_in_node_s_for) < 0) __PYX_ERR(0, 104, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":105
 * st_NoCostFct = 'Sorry, the cost function is unknown'
 * st_ActivationError = "Activation error %s in node='%s' for activation='%s', potential=%f"
 * st_ActivationDerivativeError = "Activation derivative error %s in node='%s' for activation='%s', potential=%f"             # <<<<<<<<<<<<<<
 * st_ActivationDerivative2Error = "Activation second derivative error %s in node='%s' for activation='%s', potential=%f, derivative=%f"
 * st_NeedNetDef = "need a path to model file, or a network definition"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_ActivationDerivativeError, __pyx_kp_u_Activation_derivative_error_s_in) < 0) __PYX_ERR(0, 105, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":106
 * st_ActivationError = "Activation error %s in node='%s' for activation='%s', potential=%f"
 * st_ActivationDerivativeError = "Activation derivative error %s in node='%s' for activation='%s', potential=%f"
 * st_ActivationDerivative2Error = "Activation second derivative error %s in node='%s' for activation='%s', potential=%f, derivative=%f"             # <<<<<<<<<<<<<<
 * st_NeedNetDef = "need a path to model file, or a network definition"
 * st_negativeInput = 'negative number of inputs + outputs'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_ActivationDerivative2Error, __pyx_kp_u_Activation_second_derivative_err) < 0) __PYX_ERR(0, 106, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":107
 * st_ActivationDerivativeError = "Activation derivative error %s in node='%s' for activation='%s', potential=%f"
 * st_ActivationDerivative2Error = "Activation second derivative error %s in node='%s' for activation='%s', potential=%f, derivative=%f"
 * st_NeedNetDef = "need a path to model file, or a network definition"             # <<<<<<<<<<<<<<
 * st_negativeInput = 'negative number of inputs + outputs'
 * st_NeedFunctionName = 'Need at least a function name'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_NeedNetDef, __pyx_kp_u_need_a_path_to_model_file_or_a_n) < 0) __PYX_ERR(0, 107, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":108
 * st_ActivationDerivative2Error = "Activation second derivative error %s in node='%s' for activation='%s', potential=%f, derivative=%f"
 * st_NeedNetDef = "need a path to model file, or a network definition"
 * st_negativeInput = 'negative number of inputs + outputs'             # <<<<<<<<<<<<<<
 * st_NeedFunctionName = 'Need at least a function name'
 * st_CostFuncUnknown = 'Cost function "%s" unknown'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_negativeInput, __pyx_kp_u_negative_number_of_inputs_output) < 0) __PYX_ERR(0, 108, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":109
 * st_NeedNetDef = "need a path to model file, or a network definition"
 * st_negativeInput = 'negative number of inputs + outputs'
 * st_NeedFunctionName = 'Need at least a function name'             # <<<<<<<<<<<<<<
 * st_CostFuncUnknown = 'Cost function "%s" unknown'
 * st_BadInputNb = "Bad input number"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_NeedFunctionName, __pyx_kp_u_Need_at_least_a_function_name) < 0) __PYX_ERR(0, 109, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":110
 * st_negativeInput = 'negative number of inputs + outputs'
 * st_NeedFunctionName = 'Need at least a function name'
 * st_CostFuncUnknown = 'Cost function "%s" unknown'             # <<<<<<<<<<<<<<
 * st_BadInputNb = "Bad input number"
 * st_IndexErrorWithLimits = "Index Error. Should be %d <= %d < %d"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_CostFuncUnknown, __pyx_kp_u_Cost_function_s_unknown) < 0) __PYX_ERR(0, 110, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":111
 * st_NeedFunctionName = 'Need at least a function name'
 * st_CostFuncUnknown = 'Cost function "%s" unknown'
 * st_BadInputNb = "Bad input number"             # <<<<<<<<<<<<<<
 * st_IndexErrorWithLimits = "Index Error. Should be %d <= %d < %d"
 * st_NamedIndexErrorWithLimits = "%s Index Error. Should be %d <= (%d) < %d"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_BadInputNb, __pyx_kp_u_Bad_input_number) < 0) __PYX_ERR(0, 111, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":112
 * st_CostFuncUnknown = 'Cost function "%s" unknown'
 * st_BadInputNb = "Bad input number"
 * st_IndexErrorWithLimits = "Index Error. Should be %d <= %d < %d"             # <<<<<<<<<<<<<<
 * st_NamedIndexErrorWithLimits = "%s Index Error. Should be %d <= (%d) < %d"
 * st_CostComputeDisp = "Cost compute %s line=%d for vcal=%f, vdes=%s"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_IndexErrorWithLimits, __pyx_kp_u_Index_Error_Should_be_d_d_d) < 0) __PYX_ERR(0, 112, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":113
 * st_BadInputNb = "Bad input number"
 * st_IndexErrorWithLimits = "Index Error. Should be %d <= %d < %d"
 * st_NamedIndexErrorWithLimits = "%s Index Error. Should be %d <= (%d) < %d"             # <<<<<<<<<<<<<<
 * st_CostComputeDisp = "Cost compute %s line=%d for vcal=%f, vdes=%s"
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_NamedIndexErrorWithLimits, __pyx_kp_u_s_Index_Error_Should_be_d_d_d) < 0) __PYX_ERR(0, 113, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":114
 * st_IndexErrorWithLimits = "Index Error. Should be %d <= %d < %d"
 * st_NamedIndexErrorWithLimits = "%s Index Error. Should be %d <= (%d) < %d"
 * st_CostComputeDisp = "Cost compute %s line=%d for vcal=%f, vdes=%s"             # <<<<<<<<<<<<<<
 * 
 * st_INdefault = 'IN_%d'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_CostComputeDisp, __pyx_kp_u_Cost_compute_s_line_d_for_vcal_f) < 0) __PYX_ERR(0, 114, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":116
 * st_CostComputeDisp = "Cost compute %s line=%d for vcal=%f, vdes=%s"
 * 
 * st_INdefault = 'IN_%d'             # <<<<<<<<<<<<<<
 * st_OUTdefault = 'OUT_%d'
 * st_HIDdefault = 'H%d_%d'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_INdefault, __pyx_kp_u_IN__d) < 0) __PYX_ERR(0, 116, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":117
 * 
 * st_INdefault = 'IN_%d'
 * st_OUTdefault = 'OUT_%d'             # <<<<<<<<<<<<<<
 * st_HIDdefault = 'H%d_%d'
 * st_WEIGHTdefault = 'W_%d'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_OUTdefault, __pyx_kp_u_OUT__d) < 0) __PYX_ERR(0, 117, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":118
 * st_INdefault = 'IN_%d'
 * st_OUTdefault = 'OUT_%d'
 * st_HIDdefault = 'H%d_%d'             # <<<<<<<<<<<<<<
 * st_WEIGHTdefault = 'W_%d'
 * st_normName = 'N_%s'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_HIDdefault, __pyx_kp_u_H_d__d) < 0) __PYX_ERR(0, 118, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":119
 * st_OUTdefault = 'OUT_%d'
 * st_HIDdefault = 'H%d_%d'
 * st_WEIGHTdefault = 'W_%d'             # <<<<<<<<<<<<<<
 * st_normName = 'N_%s'
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_WEIGHTdefault, __pyx_kp_u_W__d) < 0) __PYX_ERR(0, 119, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":120
 * st_HIDdefault = 'H%d_%d'
 * st_WEIGHTdefault = 'W_%d'
 * st_normName = 'N_%s'             # <<<<<<<<<<<<<<
 * 
 * st_XMLHeader = '<?xml version="%s" encoding="%s"?>'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_normName, __pyx_kp_u_N__s) < 0) __PYX_ERR(0, 120, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":122
 * st_normName = 'N_%s'
 * 
 * st_XMLHeader = '<?xml version="%s" encoding="%s"?>'             # <<<<<<<<<<<<<<
 * st_XMLStyleSheet = '<?xml-stylesheet type="text/xsl"?>'
 * st_xmlns_xsi = "xmlns:xsi"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_XMLHeader, __pyx_kp_u_xml_version_s_encoding_s) < 0) __PYX_ERR(0, 122, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":123
 * 
 * st_XMLHeader = '<?xml version="%s" encoding="%s"?>'
 * st_XMLStyleSheet = '<?xml-stylesheet type="text/xsl"?>'             # <<<<<<<<<<<<<<
 * st_xmlns_xsi = "xmlns:xsi"
 * st_XMLSchema = "http://www.w3.org/2001/XMLSchema-instance"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_XMLStyleSheet, __pyx_kp_u_xml_stylesheet_type_text_xsl) < 0) __PYX_ERR(0, 123, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":124
 * st_XMLHeader = '<?xml version="%s" encoding="%s"?>'
 * st_XMLStyleSheet = '<?xml-stylesheet type="text/xsl"?>'
 * st_xmlns_xsi = "xmlns:xsi"             # <<<<<<<<<<<<<<
 * st_XMLSchema = "http://www.w3.org/2001/XMLSchema-instance"
 * st_XMLSchemaLoc = "xsi:noNamespaceSchemaLocation"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_xmlns_xsi, __pyx_kp_u_xmlns_xsi) < 0) __PYX_ERR(0, 124, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":125
 * st_XMLStyleSheet = '<?xml-stylesheet type="text/xsl"?>'
 * st_xmlns_xsi = "xmlns:xsi"
 * st_XMLSchema = "http://www.w3.org/2001/XMLSchema-instance"             # <<<<<<<<<<<<<<
 * st_XMLSchemaLoc = "xsi:noNamespaceSchemaLocation"
 * st_ModelURL = "http://www.netral.com/public/xml/xsd/model.xsd"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_XMLSchema, __pyx_kp_u_http_www_w3_org_2001_XMLSchema_i) < 0) __PYX_ERR(0, 125, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":126
 * st_xmlns_xsi = "xmlns:xsi"
 * st_XMLSchema = "http://www.w3.org/2001/XMLSchema-instance"
 * st_XMLSchemaLoc = "xsi:noNamespaceSchemaLocation"             # <<<<<<<<<<<<<<
 * st_ModelURL = "http://www.netral.com/public/xml/xsd/model.xsd"
 * st_XMLVersion = "1.0"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_XMLSchemaLoc, __pyx_kp_u_xsi_noNamespaceSchemaLocation) < 0) __PYX_ERR(0, 126, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":127
 * st_XMLSchema = "http://www.w3.org/2001/XMLSchema-instance"
 * st_XMLSchemaLoc = "xsi:noNamespaceSchemaLocation"
 * st_ModelURL = "http://www.netral.com/public/xml/xsd/model.xsd"             # <<<<<<<<<<<<<<
 * st_XMLVersion = "1.0"
 * st_XMLEncoding = "ISO-8859-1"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_ModelURL, __pyx_kp_u_http_www_netral_com_public_xml_x) < 0) __PYX_ERR(0, 127, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":128
 * st_XMLSchemaLoc = "xsi:noNamespaceSchemaLocation"
 * st_ModelURL = "http://www.netral.com/public/xml/xsd/model.xsd"
 * st_XMLVersion = "1.0"             # <<<<<<<<<<<<<<
 * st_XMLEncoding = "ISO-8859-1"
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_XMLVersion, __pyx_kp_u_1_0) < 0) __PYX_ERR(0, 128, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":129
 * st_ModelURL = "http://www.netral.com/public/xml/xsd/model.xsd"
 * st_XMLVersion = "1.0"
 * st_XMLEncoding = "ISO-8859-1"             # <<<<<<<<<<<<<<
 * 
 * class ConstError(TypeError): pass
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_st_XMLEncoding, __pyx_kp_u_ISO_8859_1) < 0) __PYX_ERR(0, 129, __pyx_L1_error)

  /* "metaphor/monal/util/const_st.py":131
 * st_XMLEncoding = "ISO-8859-1"
 * 
 * class ConstError(TypeError): pass             # <<<<<<<<<<<<<<
 * 
 * #def __setattr__(self, name, value):
 */
  __pyx_t_3 = __Pyx_CalculateMetaclass(NULL, __pyx_tuple_); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare(__pyx_t_3, __pyx_tuple_, __pyx_n_s_ConstError, __pyx_n_s_ConstError, (PyObject *) NULL, __pyx_n_s_metaphor_monal_util_const_st, (PyObject *) NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_3, __pyx_n_s_ConstError, __pyx_tuple_, __pyx_t_4, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ConstError, __pyx_t_2) < 0) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "metaphor/monal/util/const_st.py":1
 * # -*- coding: UTF-8 -*-             # <<<<<<<<<<<<<<
 * #===============================================================================
 * # $Id: const_st.py 4127 2016-04-30 06:49:53Z jeanluc $
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init metaphor.monal.util.const_st", 0, __pyx_lineno, __pyx_filename);
    }
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init metaphor.monal.util.const_st");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* GetModuleGlobalName */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    if (likely(result)) {
        Py_INCREF(result);
    } else if (unlikely(PyErr_Occurred())) {
        result = NULL;
    } else {
#else
    result = PyDict_GetItem(__pyx_d, name);
    if (likely(result)) {
        Py_INCREF(result);
    } else {
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

/* CalculateMetaclass */
    static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases = PyTuple_GET_SIZE(bases);
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* Py3ClassCreate */
    static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStr(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs = PyTuple_Pack(2, name, bases);
            if (unlikely(!pargs)) {
                Py_DECREF(prep);
                return NULL;
            }
            ns = PyObject_Call(prep, pargs, mkw);
            Py_DECREF(prep);
            Py_DECREF(pargs);
        } else {
            if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError)))
                return NULL;
            PyErr_Clear();
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result, *margs;
    PyObject *owned_metaclass = NULL;
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    margs = PyTuple_Pack(3, name, bases, dict);
    if (unlikely(!margs)) {
        result = NULL;
    } else {
        result = PyObject_Call(metaclass, margs, mkw);
        Py_DECREF(margs);
    }
    Py_XDECREF(owned_metaclass);
    return result;
}

/* PyErrFetchRestore */
    #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* CLineInTraceback */
    #ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
      use_cline = __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback);
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (PyObject_Not(use_cline) != 0) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
    static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
    #include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntToPy */
    static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPyVerify */
    #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
    static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
    static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
    #if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
    static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
    static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(x);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
